@@ -143,7 +143,6 @@ class Choice(object):
     <Choice[2]:None>
     >>> str(choice)
     'None'
-
     '''
     order = 0
 
@@ -185,6 +184,9 @@ class Choice(object):
         elif six.PY3:
             return six.text_type(label)
 
+    def __hash__(self):
+        return hash(self.value)
+
     def deconstruct(self):
         return (
             '{}.{}'.format(self.__class__.__module__, self.__class__.__name__),
