@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import sys
 from . import base_command
 
@@ -6,9 +8,8 @@ try:
         import Command
 except ImportError:
     class Command(base_command.CustomBaseCommand):
-        def handle(self, *args, **kwargs):
-            print >>sys.stderr, (
-                'This command has been moved to the `django_admin_generator` '
-                'package. Please use `pip install django_admin_generator` to '
-                'install')
 
+        def handle(self, *args, **kwargs):
+            print('This command has been moved to the `django_admin_generator`'
+                  ' package. Please use `pip install django_admin_generator` '
+                  'to install', file=sys.stderr)
